pub enum CURIEParsingError {
UnknownControlledVocabulary(ControlledVocabularyResolutionError),
AccessionParsingError(ParseIntError),
MissingNamespaceSeparator,
}Variants
UnknownControlledVocabulary(ControlledVocabularyResolutionError)
Indicates that the controlled vocabulary wasn’t recognized, even if it is perfectly valid, we just don’t cover it.
AccessionParsingError(ParseIntError)
Indicates that the accession code wasn’t successfully parsed into an integer. Non-numeric accession codes are not supported by this library.
MissingNamespaceSeparator
Indicates that a “:” wasn’t detected, which indicates a malformed CURIE anywhere.