pub enum ParamValueParseError {
FailedToExtractFloat(Option<String>),
FailedToExtractInt(Option<String>),
FailedToExtractString,
FailedToExtractBuffer,
}Expand description
Errors that might occur while trying to convert to a particular value type
from whatever type might be stored in a ParamValue-like object.
Variants
FailedToExtractFloat(Option<String>)
The value could not be interpreted as a floating point number.
FailedToExtractInt(Option<String>)
The value could not be interpreted as an integer.
FailedToExtractString
The value could not be interpreted as a string.
FailedToExtractBuffer
The value could not be interpreted as a byte buffer.