pub enum ValueRef<'a> {
String(Cow<'a, str>),
Float(f64),
Int(i64),
Buffer(Cow<'a, [u8]>),
Empty,
Boolean(bool),
List(Cow<'a, [Value]>),
}Expand description
A borrowed parameter value that may be a string, a number, or empty. It is intended to
be paired with the ParamValue trait.
The owned equivalent of this type is Value.
Variants
String(Cow<'a, str>)
A text value of arbitrary length
Float(f64)
A floating point number
Int(i64)
A integral number
Buffer(Cow<'a, [u8]>)
Arbitrary binary data
Empty
No value specified
Boolean(bool)
A true/false value
List(Cow<'a, [Value]>)
A collection of heterogenous Value
Implementations
Sourceimpl<'a> ValueRef<'a>
impl<'a> ValueRef<'a>
Sourcepub fn new(s: &'a str) -> Self
pub fn new(s: &'a str) -> Self
Convert a string value into a precise value type by trying successive types to parse, defaulting to storing the string as-is.
Sourcepub fn coerce_bool(&mut self) -> Result<(), ParamValueParseError>
pub fn coerce_bool(&mut self) -> Result<(), ParamValueParseError>
Store the value as a boolean
Sourcepub fn coerce_f64(&mut self) -> Result<(), ParamValueParseError>
pub fn coerce_f64(&mut self) -> Result<(), ParamValueParseError>
Store the value as a floating point number
Sourcepub fn coerce_i64(&mut self) -> Result<(), ParamValueParseError>
pub fn coerce_i64(&mut self) -> Result<(), ParamValueParseError>
Store the value as an integer
Sourcepub fn coerce_str(&mut self) -> Result<(), ParamValueParseError>
pub fn coerce_str(&mut self) -> Result<(), ParamValueParseError>
Store the value as a string
Sourcepub fn coerce_empty(&mut self)
pub fn coerce_empty(&mut self)
Discard the value, leaving this value ValueRef::Empty
Sourcepub fn coerce_buffer(&mut self) -> Result<(), ParamValueParseError>
pub fn coerce_buffer(&mut self) -> Result<(), ParamValueParseError>
Store the value as a byte buffer
Sourcepub fn coerce_list(&mut self) -> Result<(), ParamValueParseError>
pub fn coerce_list(&mut self) -> Result<(), ParamValueParseError>
Store the value as a list