impl_param_described_deferred

Macro impl_param_described_deferred 

macro_rules! impl_param_described_deferred {
    ($($t:ty), +) => { ... };
}
Implement the ParamDescribed trait for type $t, referencing a params member that is an Option<Vec<Param>> that will lazily be initialized automatically when it is accessed mutably.