CURIE

Struct CURIE 

pub struct CURIE {
    pub controlled_vocabulary: ControlledVocabulary,
    pub accession: AccessionIntCode,
}
A CURIE is a namespace + accession identifier, of the form <namespace>:<identifier>.

A CURIE is a “compact URI”: https://www.w3.org/TR/curie/. This implementation assumes that that the accession code is a number and that an accession code is always present, which is not universally true. It is however sufficient for most use-cases in this library’s domain.

Fields

controlled_vocabulary: ControlledVocabulary

The controlled vocabulary namespace, e.g. MS.

accession: AccessionIntCode

The numeric accession code within the namespace, e.g. 1000016.

Implementations

Source

impl CURIE

pub const fn new( cv_id: ControlledVocabulary, accession: AccessionIntCode, ) -> Self

Build a CURIE from a namespace and accession code directly.

This is a const function, but it cannot be used in a context that does not allow function calls. Prefer the curie macro when writing “constant” CURIEs

pub fn as_param(&self) -> Param

Create an otherwise-empty Param carrying this CURIE’s namespace and accession, with an empty name and value.

This is technically valid, but most users will also expect Param::name to be set.

pub const fn accession_int(&self) -> u32

The numeric accession code, equivalent to reading CURIE::accession directly.

pub const fn controlled_vocabulary(&self) -> ControlledVocabulary

The controlled vocabulary namespace, equivalent to reading CURIE::controlled_vocabulary directly.