Param

Struct Param 

pub struct Param {
    pub name: String,
    pub value: Value,
    pub accession: Option<AccessionIntCode>,
    pub controlled_vocabulary: Option<ControlledVocabulary>,
    pub unit: Unit,
}
A controlled vocabulary or user parameter

Fields

name: String

The human-readable name of the parameter.

value: Value

A type generic value associated with the parameter

accession: Option<AccessionIntCode>

The numeric component of the accession code in the identifier for the parameter’s definition in Self::controlled_vocabulary, if it is defined by one.

controlled_vocabulary: Option<ControlledVocabulary>

The controlled vocabulary this parameter is defined in, if any.

unit: Unit

The unit the parameter’s value is expressed in, if any.

Implementations

Source

impl Param

pub fn new() -> Param

pub fn builder() -> ParamBuilder

Create a new ParamBuilder to make creating a new Param more convenient than setting fields on a bare Param directly.

pub fn new_key_value<K: Into<String>, V: Into<Value>>( name: K, value: V, ) -> Param

A construction method for Param that sets Param::name and Param::value but leaves all other attributes as default.

pub fn parse<T: FromStr>(&self) -> Result<T, T::Err>

Attempt to parse the value of this parameter into T.

See Value::parse

pub const fn is_controlled(&self) -> bool

Check if this parameter is defined in a controlled vocabulary

pub const fn curie(&self) -> Option<CURIE>

pub fn curie_str(&self) -> Option<String>

Format the Param::curie as a string, if it exists

pub fn with_unit<S: AsRef<str>, A: AsRef<str>>( self, accession: S, name: A, ) -> Param

Update Param::unit inferred from accession, failing that, name

See also
pub fn with_unit_t(self, unit: &Unit) -> Param

Set Param::unit directly from unit.

See also