Elements of controlled vocabularies used to describe mass spectra and their components.
Directly maps to the usage of the PSI-MS controlled vocabulary in mzML
Macros
- curie
- A syntactic shortcut for creating
CURIEinstances using compact notation - find_
param_ method - A helper to generate methods that find a value by a
CURIE - impl_
param_ described - Implement the
ParamDescribedtrait for type$t, referencing aparamsmember of typeVec<Param>. - impl_
param_ described_ deferred - Implement the
ParamDescribedtrait for type$t, referencing aparamsmember that is anOption<Vec<Param>>that will lazily be initialized automatically when it is accessed mutably.
Structs
- CURIE
- A CURIE is a namespace + accession identifier
- Param
- A controlled vocabulary or user parameter
- Param
Builder - Incrementally build up a
Param - Param
Cow - A statically allocate-able or non-owned data version of
Param
Enums
- Accession
Code Parse Error - Accession
Like - Anything that can be converted into an accession code portion of a
CURIE - CURIE
Parsing Error - Controlled
Vocabulary - Controlled vocabularies used in mass spectrometry data files
- Controlled
Vocabulary Resolution Error - An error describing a failure to map a controlled vocabulary identifier to a known namespace
- Param
Value Parse Error - Errors that might occur while trying to convert to a particular value type
from whatever type might be stored in a
ParamValue-like object. - Unit
- Units that a term’s value might have
- Value
- An owned parameter value that may be a string, a number, or empty. It is intended to
be paired with the
ParamValuetrait. - Value
Ref - A borrowed parameter value that may be a string, a number, or empty. It is intended to
be paired with the
ParamValuetrait.
Traits
- Param
Described - A type that has a
ParamListthat usesParaminstances to describe an entity with key-value pairs. - Param
Described Read - A read-only form of
ParamDescribed - Param
Like - Describe a controlled vocabulary parameter or a user-defined parameter
- Param
Value - Access a parameter’s value, with specific coercion rules and eager type conversion.