Crate mzdata_param

Crate mzdata_param 

Elements of controlled vocabularies used to describe mass spectra and their components.

Directly maps to the usage of the PSI-MS controlled vocabulary in mzML

Macros

curie
A syntactic shortcut for creating CURIE instances using compact notation
find_param_method
A helper to generate methods that find a value by a CURIE
impl_param_described
Implement the ParamDescribed trait for type $t, referencing a params member of type Vec<Param>.
impl_param_described_deferred
Implement the ParamDescribed trait for type $t, referencing a params member that is an Option<Vec<Param>> that will lazily be initialized automatically when it is accessed mutably.

Structs

CURIE
A CURIE is a namespace + accession identifier
Param
A controlled vocabulary or user parameter
ParamBuilder
Incrementally build up a Param
ParamCow
A statically allocate-able or non-owned data version of Param

Enums

AccessionCodeParseError
AccessionLike
Anything that can be converted into an accession code portion of a CURIE
CURIEParsingError
ControlledVocabulary
Controlled vocabularies used in mass spectrometry data files
ControlledVocabularyResolutionError
An error describing a failure to map a controlled vocabulary identifier to a known namespace
ParamValueParseError
Errors that might occur while trying to convert to a particular value type from whatever type might be stored in a ParamValue-like object.
Unit
Units that a term’s value might have
Value
An owned parameter value that may be a string, a number, or empty. It is intended to be paired with the ParamValue trait.
ValueRef
A borrowed parameter value that may be a string, a number, or empty. It is intended to be paired with the ParamValue trait.

Traits

ParamDescribed
A type that has a ParamList that uses Param instances to describe an entity with key-value pairs.
ParamDescribedRead
A read-only form of ParamDescribed
ParamLike
Describe a controlled vocabulary parameter or a user-defined parameter
ParamValue
Access a parameter’s value, with specific coercion rules and eager type conversion.

Functions

curie_to_num

Type Aliases

AccessionIntCode
ParamList