#[repr(u8)]pub enum ControlledVocabulary {
MS = 1,
UO = 2,
EFO = 3,
OBI = 4,
HANCESTRO = 5,
BFO = 6,
NCIT = 7,
BTO = 8,
PRIDE = 9,
Unknown = 10,
}Expand description
Controlled vocabularies used in mass spectrometry data files
Variants
MS = 1
The PSI-MS Controlled Vocabulary https://www.ebi.ac.uk/ols4/ontologies/ms
UO = 2
The Unit Ontology https://www.ebi.ac.uk/ols4/ontologies/uo
EFO = 3
The Experimental Factor Ontology https://www.ebi.ac.uk/ols4/ontologies/efo
OBI = 4
The Ontology for Biomedical Investigations https://www.ebi.ac.uk/ols4/ontologies/obi
HANCESTRO = 5
The Human Ancestry Ontology https://www.ebi.ac.uk/ols4/ontologies/hancestro
BFO = 6
The Basic Formal Ontology https://www.ebi.ac.uk/ols4/ontologies/bfo
NCIT = 7
The NCI Thesaurus OBO Edition https://www.ebi.ac.uk/ols4/ontologies/ncit
BTO = 8
The BRENDA Tissue Ontology https://www.ebi.ac.uk/ols4/ontologies/bto
PRIDE = 9
The PRIDE Controlled Vocabulary https://www.ebi.ac.uk/ols4/ontologies/pride
Unknown = 10
Implementations
Sourceimpl<'a> ControlledVocabulary
impl<'a> ControlledVocabulary
Sourcepub const fn prefix(&self) -> Cow<'static, str>
pub const fn prefix(&self) -> Cow<'static, str>
Get the CURIE namespace prefix for this controlled vocabulary
Sourcepub const fn as_bytes(&self) -> &'static [u8] ⓘ
pub const fn as_bytes(&self) -> &'static [u8] ⓘ
Like ControlledVocabulary::prefix, but obtain a byte string instead
pub const fn as_option(&self) -> Option<Self>
Sourcepub fn param<A: Into<AccessionLike<'a>>, S: Into<String>>(
&self,
accession: A,
name: S,
) -> Param
pub fn param<A: Into<AccessionLike<'a>>, S: Into<String>>( &self, accession: A, name: S, ) -> Param
pub const fn curie(&self, accession: AccessionIntCode) -> CURIE
Sourcepub const fn const_param(
&self,
name: &'static str,
value: ValueRef<'static>,
accession: AccessionIntCode,
unit: Unit,
) -> ParamCow<'static>
pub const fn const_param( &self, name: &'static str, value: ValueRef<'static>, accession: AccessionIntCode, unit: Unit, ) -> ParamCow<'static>
Create a ParamCow from this namespace in a const context, useful for preparing
global constants or inlined variables.
All parameters must have a 'static lifetime.
Arguments
name: The name of the controlled vocabulary term.value: The wrapped value as a constant.accession: The a priori determined accession code for the termunit: The unit associated with the value
Sourcepub const fn const_param_ident(
&self,
name: &'static str,
accession: AccessionIntCode,
) -> ParamCow<'static>
pub const fn const_param_ident( &self, name: &'static str, accession: AccessionIntCode, ) -> ParamCow<'static>
Create a ParamCow from this namespace in a const context with an empty
value and no unit.
See ControlledVocabulary::const_param for more details.
Sourcepub const fn const_param_ident_unit(
&self,
name: &'static str,
accession: AccessionIntCode,
unit: Unit,
) -> ParamCow<'static>
pub const fn const_param_ident_unit( &self, name: &'static str, accession: AccessionIntCode, unit: Unit, ) -> ParamCow<'static>
Create a ParamCow from this namespace in a const context with an empty
value but a specified unit.
This is intended to create a “template” that will be copied and have a value specified.
See ControlledVocabulary::const_param for more details.
Sourcepub fn param_val<S: Into<String>, A: Into<AccessionLike<'a>>, V: Into<Value>>(
&self,
accession: A,
name: S,
value: V,
) -> Param
pub fn param_val<S: Into<String>, A: Into<AccessionLike<'a>>, V: Into<Value>>( &self, accession: A, name: S, value: V, ) -> Param
Create a Param whose accession comes from this controlled vocabulary namespace with
the given value.
Arguments
accession: The accession code for theParam. If specified as aCURIEor a string-like type, any namespace is ignored.name: The name of the parametervalue: The value of the parameter
See Also